Python Templates
================

`Python Templates`_ is an Apache2 licensed `html templating`_ library, written
in pure-Python, including popular HTML templates like `Bootstrap`_.

.. _`Python Templates`: http://www.grantjenks.com/docs/templates/
.. _`html templating`: http://www.grantjenks.com/docs/templates/
.. _`Bootstrap`: https://getbootstrap.com/

Testimonials
------------

Does your company or website use `Python Templates`_? Send us a `message
<contact@grantjenks.com>`_ and let us know.

Features
--------

- Pure-Python
- Popular HTML templates included!

Quickstart
----------

Installing `Python Templates`_ is simple with `pip
<https://pypi.org/project/pip/>`_::

    $ pip install templates

You can access documentation in the interpreter with Python's built-in `help`
function. The `help` works on modules, classes and methods in `Python Templates`_.

.. code-block:: python

    >>> import templates
    >>> help(templates)
    >>> from templates import bootstrap
    >>> help(bootstrap)

Useful Links
------------

- `Python Templates Documentation`_
- `Python Templates at PyPI`_
- `Python Templates at Github`_
- `Python Templates Issue Tracker`_

.. _`Python Templates Documentation`: http://www.grantjenks.com/docs/templates/
.. _`Python Templates at PyPI`: https://pypi.org/project/templates/
.. _`Python Templates at Github`: https://github.com/grantjenks/python-templates
.. _`Python Templates Issue Tracker`: https://github.com/grantjenks/python-templates/issues

Python Templates License
------------------------

Copyright 2018 Grant Jenks

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
